========================================
 OpenStack Dashboard User Documentation
========================================

As a cloud end user, you can use the OpenStack dashboard to provision
your own resources within the limits set by administrators. You can
modify the examples provided in this section to create other types and
sizes of server instances.

.. toctree::
   :maxdepth: 2

   log-in.rst
   manage-images.rst
   configure-access-and-security-for-instances.rst
   launch-instances.rst
   create-networks.rst
   manage-containers.rst
   manage-volumes.rst
   browser_support
